@@ -317,8 +317,9 @@ except TypeError:
 
 
 
-#创建不存在的目录
+
 def check_dir(path):
+    '''检查目录，如不存在则新建'''
     if not os.path.isdir(path):
         os.makedirs(path)
         return "Create Successful."
\ No newline at end of file
